@@ -1,11 +1,6 @@
-//@line 40 "/export/home/mozilla/uild/firefox-1.5.0.12/src/mozilla/toolkit/content/customizeToolbar.js"
+//@line 40 "/export/home/mozilla/uild/firefox-2.0.0.14/src/mozilla/toolkit/content/customizeToolbar.js"
 
 const kRowMax = 4;
-const kWindowWidth = 635;
-const kWindowHeight = 400;
-const kAnimateIncrement = 50;
-const kAnimateSteps = kWindowHeight / kAnimateIncrement - 1;
-const kVSizeSlop = 5;
 
 var gToolboxDocument = null;
 var gToolbox = null;
@@ -15,7 +10,13 @@ var gToolboxIconSize = false;
 
 function onLoad()
 {
-  gToolbox = window.arguments[0];
+  InitWithToolbox(window.arguments[0]);
+  repositionDialog();
+}
+
+function InitWithToolbox(aToolbox)
+{
+  gToolbox = aToolbox;
   gToolboxDocument = gToolbox.ownerDocument;
   
   gToolbox.addEventListener("draggesture", onToolbarDragGesture, false);
@@ -23,19 +24,21 @@ function onLoad()
   gToolbox.addEventListener("dragexit", onToolbarDragExit, false);
   gToolbox.addEventListener("dragdrop", onToolbarDragDrop, false);
 
-  repositionDialog();
-  
   initDialog();
 }
 
-function onUnload(aEvent)
+function finishToolbarCustomization()
 {
   removeToolboxListeners();
   unwrapToolbarItems();
   persistCurrentSets();
   
   notifyParentComplete();
-  
+}
+
+function onUnload(aEvent)
+{
+  finishToolbarCustomization();
   window.close();
 }
 
@@ -68,17 +71,16 @@ function initDialog()
 function repositionDialog()
 {
   // Position the dialog touching the bottom of the toolbox and centered with 
-  // it. We must resize the window smaller first so that it is positioned 
-  // properly. 
-  var screenX = gToolbox.boxObject.screenX + ((gToolbox.boxObject.width - kWindowWidth) / 2);
+  // it.
+  var width;
+  if (document.documentElement.hasAttribute("width"))
+    width = document.documentElement.getAttribute("width");
+  else
+    width = parseInt(document.documentElement.style.width);
+  var screenX = gToolbox.boxObject.screenX 
+                + ((gToolbox.boxObject.width - width) / 2);
   var screenY = gToolbox.boxObject.screenY + gToolbox.boxObject.height;
 
-  var newHeight = kWindowHeight;
-  if (newHeight >= screen.availHeight - screenY - kVSizeSlop) {
-    newHeight = screen.availHeight - screenY - kVSizeSlop;
-  }
-
-  window.resizeTo(kWindowWidth, newHeight);
   window.moveTo(screenX, screenY);
 }
 
@@ -525,7 +527,6 @@ function addNewToolbar()
     
   gToolbox.appendCustomToolbar(name.value, "");
   
-  repositionDialog();
   gToolboxChanged = true;
 }
 
@@ -579,7 +580,6 @@ function restoreDefaultSet()
   // Restore the disabled and command states
   restoreItemAttributes(["itemdisabled", "itemcommand"], savedAttributes);
 
-  repositionDialog();
   gToolboxChanged = true;
 }
 
@@ -634,8 +634,6 @@ function updateIconSize(aUseSmallIcons)
       gToolboxDocument.persist(toolbar.id, "iconsize");
     }
   }
-
-  repositionDialog();
 }
 
 function updateToolbarMode(aModeValue)
@@ -653,8 +651,6 @@ function updateToolbarMode(aModeValue)
 
   var iconSizeCheckbox = document.getElementById("smallicons");
   iconSizeCheckbox.disabled = aModeValue == "text";
-
-  repositionDialog();
 }
 
 
@@ -886,7 +882,6 @@ var toolbarDNDObserver =
     
     gCurrentDragOverItem = null;
 
-    repositionDialog();
     gToolboxChanged = true;
   },
   
@@ -943,7 +938,6 @@ var paletteDNDObserver =
       }
     }
     
-    repositionDialog();
     gToolboxChanged = true;
   },
   
